#!/usr/bin/python3

# Watch @EmojiTetra Live on ESP32 OLED Display
# https://yoursunny.com/t/2018/EmojiTetra-OLED/

import datetime
import re
import twitter
from http.server import HTTPServer, BaseHTTPRequestHandler

twttr = twitter.Api(consumer_key='XXXXXXXXXXXXXXXXXXXXXXXXX',
                    consumer_secret='XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
                    access_token_key='88888888-XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
                    access_token_secret='XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX')


class Handler(BaseHTTPRequestHandler):
    def do_GET(self):
        if self.path == '/robots.txt':
            self.handleRobotsTxt()
        elif self.path == '/emojitetra.txt':
            self.handleEmojiTetra()
        else:
            self.send_response(404)
            self.end_headers()

    def handleRobotsTxt(self):
        self.send_response(200)
        self.send_header('Content-Type', 'text/plain')
        self.end_headers()
        self.wfile.write('User-Agent: *\nDisallow: /\n'.encode('ascii'))

    def handleEmojiTetra(self):
        timeline = twttr.GetUserTimeline(
            screen_name='EmojiTetra', count=5, trim_user=True)
        ok = False
        for tweet in timeline:
            lines = tweet.text.split('\n')
            if len(lines) != 13:
                continue
            ts = datetime.datetime.strptime(
                tweet.created_at, '%a %b %d %H:%M:%S %z %Y').replace(tzinfo=None)
            since = (datetime.datetime.utcnow() - ts).total_seconds()
            match = re.search('Score\s([0-9]+)', lines[0])
            output = '{}\n{}\n'.format(since, match.group(1))
            for i, line in enumerate(lines[2:]):
                for ch in line:
                    if ch == '\u25fd':
                        output += '.'
                    else:
                        output += 'X'
                output += '\n'
            ok = True
            break

        if not ok:
            self.send_response(503)
            self.end_headers()
            return
        self.send_response(200)
        self.send_header('Content-Type', 'text/plain')
        self.end_headers()
        self.wfile.write(output.encode('ascii'))


def run(port=8000):
    httpd = HTTPServer(('', port), Handler)
    httpd.serve_forever()


if __name__ == '__main__':
    import argparse
    parser = argparse.ArgumentParser(description='EmojiTetra HTTP server.')
    parser.add_argument('--port', type=int, default=8000,
                        help='listening port number')
    args = parser.parse_args()
    run(port=args.port)
